==> mfc-api-model-0.1.3-sources.jar: com/valor/mfc/vms/api/model/meta/playlist/v1/PlaylistMetaDO.java <==
package com.valor.mfc.vms.api.model.meta.playlist.v1;

import com.valor.mfc.vms.api.model.constant.EPlaylistShowType;
import com.valor.mfc.vms.api.model.constant.EPlaylistType;
import com.valor.mfc.vms.api.model.meta.base.v1.BaseMetaDO;

import java.util.Map;

/**
 * Project     : volor
 * Description :
 * Author      : Frank
 * Create Time : 2016/1/8 11:09
 */
public class PlaylistMetaDO extends BaseMetaDO {
    protected String name        = "";
    protected String description = "";

    protected EPlaylistShowType showType = EPlaylistShowType.NORMAL;
    protected EPlaylistType listType ;
    protected String target = "";

    protected int    showSeq     = 0;    //show seq
    protected int    isVip       = 0;
    protected int    canFilter   = 0;
    protected boolean open;//列表是否开放

//    private Map<String, String> extra = new HashMap<>();

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public EPlaylistShowType getShowType() {
        return showType;
    }

    public void setShowType(EPlaylistShowType showType) {
        this.showType = showType;
    }

    public EPlaylistType getListType() {
        return listType;
    }

    public void setListType(EPlaylistType listType) {
        this.listType = listType;
    }

    public String getTarget() {
        return target;
    }

    public void setTarget(String target) {
        this.target = target;
    }

    public int getShowSeq() {
        return showSeq;
    }

    public void setShowSeq(int showSeq) {
        this.showSeq = showSeq;
    }

    public int getIsVip() {
        return isVip;
    }

    public void setIsVip(int isVip) {
        this.isVip = isVip;
    }

    public void setTypeStr(String type) {
        this.listType = EPlaylistType.valueOf(type);
    }

    public int getCanFilter() {
        return canFilter;
    }

    public void setCanFilter(int canFilter) {
        this.canFilter = canFilter;
    }

    public boolean isOpen() {
        return open;
    }

    public void setOpen(boolean open) {
        this.open = open;
    }
    //    public Map<String, String> getExtra() {
//        return extra;
//    }
//
//    public void setExtra(Map<String, String> extra) {
//        this.extra = extra;
//    }
}

==> mfc-api-model-0.1.7-sources.jar: com/valor/mfc/vms/api/model/meta/playlist/v1/PlaylistMetaDO.java <==
package com.valor.mfc.vms.api.model.meta.playlist.v1;

import com.valor.mfc.vms.api.model.constant.EPlaylistShowType;
import com.valor.mfc.vms.api.model.constant.EPlaylistType;
import com.valor.mfc.vms.api.model.meta.base.v1.BaseMetaDO;

import java.util.Map;

/**
 * Project     : volor
 * Description :
 * Author      : Frank
 * Create Time : 2016/1/8 11:09
 */
public class PlaylistMetaDO extends BaseMetaDO {
    protected String name        = "";
    protected String description = "";

    protected EPlaylistShowType showType = EPlaylistShowType.NORMAL;

    protected String target = "";

    protected int    showSeq     = 0;    //show seq
    protected int    isVip       = 0;
    protected int    canFilter   = 0;
    protected boolean open;//列表是否开放

//    private Map<String, String> extra = new HashMap<>();

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public EPlaylistShowType getShowType() {
        return showType;
    }

    public void setShowType(EPlaylistShowType showType) {
        this.showType = showType;
    }

    public String getTarget() {
        return target;
    }

    public void setTarget(String target) {
        this.target = target;
    }

    public int getShowSeq() {
        return showSeq;
    }

    public void setShowSeq(int showSeq) {
        this.showSeq = showSeq;
    }

    public int getIsVip() {
        return isVip;
    }

    public void setIsVip(int isVip) {
        this.isVip = isVip;
    }

    public void setTypeStr(String type) {
        this.setListType(EPlaylistType.valueOf(type));
    }

    public int getCanFilter() {
        return canFilter;
    }

    public void setCanFilter(int canFilter) {
        this.canFilter = canFilter;
    }

    public boolean isOpen() {
        return open;
    }

    public void setOpen(boolean open) {
        this.open = open;
    }
    //    public Map<String, String> getExtra() {
//        return extra;
//    }
//
//    public void setExtra(Map<String, String> extra) {
//        this.extra = extra;
//    }
}
